## 0.6.6 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.6.4 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.6.3 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 0.6.2 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 0.6.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

